==> maleo_metadata-0.0.9-py3-none-any.whl: maleo_metadata/clients/services/user_type.py <==
from fastapi import status
from maleo_foundation.utils.exceptions import BaseExceptions
from maleo_metadata.enums.general import MaleoMetadataGeneralEnums
from maleo_metadata.clients.logging import MaleoMetadataClientLoggingManager
from maleo_metadata.clients.http.controllers.user_type import MaleoMetadataUserTypeHTTPClientController
from maleo_metadata.models.transfers.parameters.general.user_type import MaleoMetadataUserTypeGeneralParametersTransfers
from maleo_metadata.models.transfers.parameters.client.user_type import MaleoMetadataUserTypeClientParametersTransfers
from maleo_metadata.models.transfers.results.general.user_type import MaleoMetadataUserTypeGeneralResultsTransfers
from maleo_metadata.types.results.general.user_type import MaleoMetadataUserTypeGeneralResultsTypes

class MaleoMetadataUserTypeClientService:
    @staticmethod
    @BaseExceptions.service_exception_handler(
        operation="retrieving user types",
        logger=MaleoMetadataClientLoggingManager.get(),
        fail_result_class=MaleoMetadataUserTypeGeneralResultsTransfers.Fail
    )
    async def get_user_types(
        parameters:MaleoMetadataUserTypeClientParametersTransfers.GetMultiple,
        controller_type:MaleoMetadataGeneralEnums.ClientControllerType = MaleoMetadataGeneralEnums.ClientControllerType.HTTP
    ) -> MaleoMetadataUserTypeGeneralResultsTypes.GetMultiple:
        """Retrieve user types from MaleoMetadata"""
        #* Validate chosen controller type
        if not isinstance(controller_type, MaleoMetadataGeneralEnums.ClientControllerType):
            message = "Invalid controller type"
            description = "The provided controller type did not exists"
            return MaleoMetadataUserTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Retrieve user types using chosen controller
        if controller_type == MaleoMetadataGeneralEnums.ClientControllerType.HTTP:
            controller_result = await MaleoMetadataUserTypeHTTPClientController.get_user_types(parameters=parameters)
        else:
            message = "Invalid controller type"
            description = "The provided controller type has not been implemented"
            return MaleoMetadataUserTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Return proper response
        if not controller_result.success:
            return MaleoMetadataUserTypeGeneralResultsTransfers.Fail.model_validate(controller_result.content)
        else:
            if controller_result.content["data"] is None:
                return MaleoMetadataUserTypeGeneralResultsTransfers.NoData.model_validate(controller_result.content)
            else:
                return MaleoMetadataUserTypeGeneralResultsTransfers.MultipleData.model_validate(controller_result.content)

    @staticmethod
    @BaseExceptions.service_exception_handler(
        operation="retrieving user type",
        logger=MaleoMetadataClientLoggingManager.get(),
        fail_result_class=MaleoMetadataUserTypeGeneralResultsTransfers.Fail
    )
    async def get_user_type(
        parameters:MaleoMetadataUserTypeGeneralParametersTransfers.GetSingle,
        controller_type:MaleoMetadataGeneralEnums.ClientControllerType = MaleoMetadataGeneralEnums.ClientControllerType.HTTP
    ) -> MaleoMetadataUserTypeGeneralResultsTypes.GetSingle:
        """Retrieve user type from MaleoMetadata"""
        #* Validate chosen controller type
        if not isinstance(controller_type, MaleoMetadataGeneralEnums.ClientControllerType):
            message = "Invalid controller type"
            description = "The provided controller type did not exists"
            return MaleoMetadataUserTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Retrieve user type using chosen controller
        if controller_type == MaleoMetadataGeneralEnums.ClientControllerType.HTTP:
            controller_result = await MaleoMetadataUserTypeHTTPClientController.get_user_type(parameters=parameters)
        else:
            message = "Invalid controller type"
            description = "The provided controller type has not been implemented"
            return MaleoMetadataUserTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Return proper response
        if not controller_result.success:
            if controller_result.status_code != status.HTTP_404_NOT_FOUND:
                return MaleoMetadataUserTypeGeneralResultsTransfers.Fail.model_validate(controller_result.content)
            else:
                return MaleoMetadataUserTypeGeneralResultsTransfers.NoData.model_validate(controller_result.content)
        else:
            return MaleoMetadataUserTypeGeneralResultsTransfers.SingleData.model_validate(controller_result.content)

==> maleo_metadata-0.0.13-py3-none-any.whl: maleo_metadata/clients/services/user_type.py <==
from fastapi import status
from maleo_foundation.utils.exceptions import BaseExceptions
from maleo_metadata.enums.general import MaleoMetadataGeneralEnums
from maleo_metadata.clients.utils.logger import MaleoMetadataClientLoggerManager
from maleo_metadata.clients.http.controllers.user_type import MaleoMetadataUserTypeHTTPClientController
from maleo_metadata.models.transfers.parameters.general.user_type import MaleoMetadataUserTypeGeneralParametersTransfers
from maleo_metadata.models.transfers.parameters.client.user_type import MaleoMetadataUserTypeClientParametersTransfers
from maleo_metadata.models.transfers.results.general.user_type import MaleoMetadataUserTypeGeneralResultsTransfers
from maleo_metadata.types.results.general.user_type import MaleoMetadataUserTypeGeneralResultsTypes

class MaleoMetadataUserTypeClientService:
    @staticmethod
    @BaseExceptions.service_exception_handler(
        operation="retrieving user types",
        logger=MaleoMetadataClientLoggerManager.get(),
        fail_result_class=MaleoMetadataUserTypeGeneralResultsTransfers.Fail
    )
    async def get_user_types(
        parameters:MaleoMetadataUserTypeClientParametersTransfers.GetMultiple,
        controller_type:MaleoMetadataGeneralEnums.ClientControllerType = MaleoMetadataGeneralEnums.ClientControllerType.HTTP
    ) -> MaleoMetadataUserTypeGeneralResultsTypes.GetMultiple:
        """Retrieve user types from MaleoMetadata"""
        #* Validate chosen controller type
        if not isinstance(controller_type, MaleoMetadataGeneralEnums.ClientControllerType):
            message = "Invalid controller type"
            description = "The provided controller type did not exists"
            return MaleoMetadataUserTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Retrieve user types using chosen controller
        if controller_type == MaleoMetadataGeneralEnums.ClientControllerType.HTTP:
            controller_result = await MaleoMetadataUserTypeHTTPClientController.get_user_types(parameters=parameters)
        else:
            message = "Invalid controller type"
            description = "The provided controller type has not been implemented"
            return MaleoMetadataUserTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Return proper response
        if not controller_result.success:
            return MaleoMetadataUserTypeGeneralResultsTransfers.Fail.model_validate(controller_result.content)
        else:
            if controller_result.content["data"] is None:
                return MaleoMetadataUserTypeGeneralResultsTransfers.NoData.model_validate(controller_result.content)
            else:
                return MaleoMetadataUserTypeGeneralResultsTransfers.MultipleData.model_validate(controller_result.content)

    @staticmethod
    @BaseExceptions.service_exception_handler(
        operation="retrieving user type",
        logger=MaleoMetadataClientLoggerManager.get(),
        fail_result_class=MaleoMetadataUserTypeGeneralResultsTransfers.Fail
    )
    async def get_user_type(
        parameters:MaleoMetadataUserTypeGeneralParametersTransfers.GetSingle,
        controller_type:MaleoMetadataGeneralEnums.ClientControllerType = MaleoMetadataGeneralEnums.ClientControllerType.HTTP
    ) -> MaleoMetadataUserTypeGeneralResultsTypes.GetSingle:
        """Retrieve user type from MaleoMetadata"""
        #* Validate chosen controller type
        if not isinstance(controller_type, MaleoMetadataGeneralEnums.ClientControllerType):
            message = "Invalid controller type"
            description = "The provided controller type did not exists"
            return MaleoMetadataUserTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Retrieve user type using chosen controller
        if controller_type == MaleoMetadataGeneralEnums.ClientControllerType.HTTP:
            controller_result = await MaleoMetadataUserTypeHTTPClientController.get_user_type(parameters=parameters)
        else:
            message = "Invalid controller type"
            description = "The provided controller type has not been implemented"
            return MaleoMetadataUserTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Return proper response
        if not controller_result.success:
            if controller_result.status_code != status.HTTP_404_NOT_FOUND:
                return MaleoMetadataUserTypeGeneralResultsTransfers.Fail.model_validate(controller_result.content)
            else:
                return MaleoMetadataUserTypeGeneralResultsTransfers.NoData.model_validate(controller_result.content)
        else:
            return MaleoMetadataUserTypeGeneralResultsTransfers.SingleData.model_validate(controller_result.content)
